@@ -44,7 +44,10 @@ def main():
     group.add_argument("--respawn", action="store_true", help=f"Respawn InfServer.")
     group.add_argument("--status", action="store_true", help=f"Get InfServer status.")
     group.add_argument(
-        "--version", action="store_true", help=f"Print versions and exit."
+        "--version", action="store_true", help=f"Print package version and exit."
+    )
+    group.add_argument(
+        "--engine-version", action="store_true", help=f"Print engine version and exit."
     )
     group.add_argument(
         "--dl-update",
@@ -107,6 +110,8 @@ def main():
             success()
             print(f"InfServer status: {status}\n")
         elif args.version:
+            print(f"\nPackage version: 0.0.11\n")
+        elif args.engine_version:
             print(f"\n{server.version()}\n")
         elif args.dl_update:
             print(" * Update data", end="")
