@@ -302,6 +302,8 @@ class InfEngineServerEngine:
                 self._logger.error(f"Can't get InfEngine version: {res}")
                 raise Exception(f"Can't get InfEngine version: {res}")
             elif process_stdout.find("Release version:") != -1:
-                return process_stdout
+                match = re.match("Release version: ([0-9a-zA-Z.-]+)", process_stdout)
+
+                return match
 
         return None
